import 'dart:io';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:ocg_app/ocg_app.dart';

import 'ui_helper.dart';

class ImageHelper {
  final BuildContext context;

  ImageHelper._(this.context);

  factory ImageHelper.of(BuildContext context) {
    return ImageHelper._(context);
  }

  Future<File> pickImage({bool isCompress = false}) async {
    try {
      String value = await AppUIHelper.of(context)
          .showModalDialog(context, ["Camera", "Gallery"]);
      PickedFile file = await ImagePicker().getImage(
          source: value == 'Camera' ? ImageSource.camera : ImageSource.gallery,
          imageQuality: isCompress ? 50 : 100);
      return File(file.path);
    } catch (e) {
      return null;
    }
  }

  Future<AppResponse<File>> pickFromCamera(
      {bool isVideo = false, int quality = 100}) async {
    try {
      PickedFile file;
      if (!isVideo) {
        file = await ImagePicker()
            .getImage(source: ImageSource.camera, imageQuality: quality);
      } else {
        file = await ImagePicker().getVideo(
          source: ImageSource.camera,
        );
      }
      return AppResponse.named(data: File(file.path));
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<File>> pickFromGalley(
      {bool isVideo = false, int quality = 100}) async {
    try {
      PickedFile file;
      if (!isVideo) {
        file = await ImagePicker()
            .getImage(source: ImageSource.gallery, imageQuality: quality);
      } else {
        file = await ImagePicker().getVideo(
          source: ImageSource.gallery,
        );
      }
      return AppResponse.named(data: File(file.path));
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }

  Future<AppResponse<List<File>>> pickFile({bool isMultiple = false}) async {
    try {
      FilePickerResult result = await FilePicker.platform
          .pickFiles(allowCompression: true, allowMultiple: isMultiple);
      return AppResponse.named(
          data: result.files.map((e) => File(e.path)).toList());
    } catch (e) {
      return AppResponse.named(error: e.toString());
    }
  }
}
