import 'package:ocg_app/src/widgets/ease_in_widget.dart';
import 'package:flutter/material.dart';

class RoundedButton extends StatelessWidget {
  final String data;
  final Function onTap;
  final bool isLoading;
  final double borderRadius;
  final Color color;
  final TextStyle style;
  final EdgeInsets padding;
  final bool isOutline;
  final IconData leadingIcon;
  const RoundedButton(
    this.data, {
    Key key,
    @required this.onTap,
    this.isLoading = false,
    this.borderRadius = 32.0,
    this.color = Colors.black,
    this.style,
    this.padding,
    this.isOutline = false,
    this.leadingIcon,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return EaseInWidget(
      onTap: onTap,
      child: Material(
        color: Colors.white,
        borderRadius: BorderRadius.circular(borderRadius),
        child: Opacity(
          opacity: !isLoading && onTap != null ? 1.0 : 0.6,
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Container(
                alignment: Alignment.center,
                padding: padding ?? EdgeInsets.symmetric(vertical: 20.0),
                decoration: BoxDecoration(
                  color: isOutline ? null : color,
                  border: isOutline ? Border.all(color: color, width: 1) : null,
                  borderRadius: BorderRadius.circular(borderRadius),
                  shape: BoxShape.rectangle,
                ),
                child: Center(
                  child: Row(
                    mainAxisSize: MainAxisSize.min,
                    children: <Widget>[
                      leadingIcon == null
                          ? Container()
                          : Icon(
                              leadingIcon,
                              color: isOutline ? color : Colors.white,
                              size: 22,
                            ),
                      SizedBox(
                        width: 8,
                      ),
                      Text(
                        data,
                        style: style ??
                            TextStyle(
                                color: isOutline ? color : Colors.white,
                                fontWeight: FontWeight.bold,
                                fontSize: 18.0),
                      ),
                      isLoading
                          ? SizedBox(
                              width: 8,
                            )
                          : Container(),
                      isLoading
                          ? Container(
                              width: 32,
                              height: 32,
                              child: CircularProgressIndicator(
                                valueColor: AlwaysStoppedAnimation<Color>(
                                    isOutline ? color : Colors.white),
                                strokeWidth: 2.0,
                              ),
                            )
                          : Container()
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
